CompositionModule
=================

.. currentmodule:: pykeen.nn.compositions

.. autoclass:: CompositionModule
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~CompositionModule.forward

   .. rubric:: Methods Documentation

   .. automethod:: forward
